@@ -1,13 +1,18 @@
 import re
+
 from ..h import E, outerHTML
 from . import steps
 
+
 class BiblioShorthand:
     def __init__(self):
         self.stage = "start"
         self.escapedText = None
         self.linkText = []
         self.bsAutolink = ""
+        self.term = None
+        self.status = None
+        self.type = None
 
     def respond(self, match, dom=None):
         if self.stage == "start":
@@ -33,36 +38,43 @@ class BiblioShorthand:
             self.stage = "end"
             return steps.NextLiteral(biblioEndRe)
 
-    def respondLinkText(self, match, dom):
+    def respondLinkText(self, match, dom):  # pylint: disable=unused-argument
         self.linkText = dom
         self.bsAutolink += outerHTML(dom)
         return self.respondEnd()
 
     def respondEnd(self):
         if self.escapedText:
-            return steps.Success(skips=["["], nodes=[self.escapedText[1:], *self.linkText, "]]"])
+            return steps.Success(
+                skips=["["], nodes=[self.escapedText[1:], *self.linkText, "]]"]
+            )
 
         self.bsAutolink += "]]"
 
         if not self.linkText:
-            self.linkText = "[{0}]".format(self.term)
+            self.linkText = f"[{self.term}]"
 
         attrs = {
-            "data-lt":self.term,
-            "data-link-type":"biblio",
-            "data-biblio-type":self.type,
-            "bs-autolink-syntax":self.bsAutolink}
+            "data-lt": self.term,
+            "data-link-type": "biblio",
+            "data-biblio-type": self.type,
+            "bs-autolink-syntax": self.bsAutolink,
+        }
         if self.status is not None:
-            attrs['data-biblio-status'] = self.status.strip()
+            attrs["data-biblio-status"] = self.status.strip()
 
         return steps.Success(E.a(attrs, self.linkText))
 
-BiblioShorthand.startRe = re.compile(r"""
+
+BiblioShorthand.startRe = re.compile(
+    r"""
     (\\)?
     \[\[
     (!)?
     ([\w.+-]+)
     (?:\s+(current|snapshot))?
-    (\|)?""", re.X)
+    (\|)?""",
+    re.X,
+)
 
-biblioEndRe = re.compile(r"]]")
\ No newline at end of file
+biblioEndRe = re.compile(r"]]")
